@@ -619,6 +619,7 @@ pub struct AxisData
 	pub max: AutoOption<f64>,
 	pub reverse: bool,
 	pub grid: bool,
+	pub is_time: bool,
 }
 
 impl AxisData
@@ -635,6 +636,7 @@ impl AxisData
 			max: Auto,
 			reverse: false,
 			grid: false,
+			is_time: false,
 		}
 	}
 
@@ -658,6 +660,15 @@ impl AxisData
 		};
 		w.write_str("\n");
 
+		w.write_str("set ");
+		w.write_str(self.axis.to_axis_str());
+		w.write_str("data");
+		if self.is_time
+		{
+			w.write_str(" time");
+		}
+		w.write_str("\n");
+
 		match self.tick_type
 		{
 			TickType::Auto(_, mticks) =>
@@ -830,7 +841,7 @@ impl AxisData
 				}
 			}
 
-			write!(w, " scale {:.12e},{:.12e}", minor_scale, major_scale);
+			write!(w, " scale {:.12e},{:.12e}", major_scale, minor_scale);
 
 			first_opt!{tick_options,
 				Format(ref f) =>
@@ -897,6 +908,11 @@ impl AxisData
 	{
 		self.grid = show;
 	}
+
+	pub fn set_time(&mut self, is_time: bool)
+	{
+		self.is_time = is_time;
+	}
 }
 
 pub fn char_to_symbol(c: char) -> i32
@@ -1454,6 +1470,69 @@ pub trait AxesCommon: AxesCommonPrivate
 		self
 	}
 
+	/// Sets the X axis be time.
+	///
+	/// If true, the axis is interpreted as seconds from the Unix epoch. Use the `Format` TickOption to
+	/// specify the formatting of the ticks (see strftime format spec for valid values).
+	///
+	/// # Arguments
+	/// * `is_time` - Whether this axis is time or not.
+	fn set_x_time<'l>(&'l mut self, is_time: bool) -> &'l mut Self
+	{
+		self.get_common_data_mut().x_axis.set_time(is_time);
+		self
+	}
+
+	/// Sets the Y axis be time. Note that the range must be non-negative for this to be valid.
+	///
+	/// If true, the axis is interpreted as seconds from the Unix epoch. Use the `Format` TickOption to
+	/// specify the formatting of the ticks (see strftime format spec for valid values).
+	///
+	/// # Arguments
+	/// * `is_time` - Whether this axis is time or not.
+	fn set_y_time<'l>(&'l mut self, is_time: bool) -> &'l mut Self
+	{
+		self.get_common_data_mut().y_axis.set_time(is_time);
+		self
+	}
+
+	/// Sets the color bar axis be time. Note that the range must be non-negative for this to be valid.
+	///
+	/// If true, the axis is interpreted as seconds from the Unix epoch. Use the `Format` TickOption to
+	/// specify the formatting of the ticks (see strftime format spec for valid values).
+	///
+	/// # Arguments
+	/// * `is_time` - Whether this axis is time or not.
+	fn set_cb_time<'l>(&'l mut self, is_time: bool) -> &'l mut Self
+	{
+		self.get_common_data_mut().cb_axis.set_time(is_time);
+		self
+	}
+
+	/// Sets the margins of the plot.
+	///
+	/// # Arguments
+	///
+	/// * `margins` - The values of margins to be overrided. Specified as a fraction of the
+	///               full drawing area, ranging from 0 to 1
+	fn set_margins<'l>(&'l mut self, margins: &[MarginSide]) -> &'l mut Self
+	{
+		{
+			let c = &mut self.get_common_data_mut().commands as &mut Writer;
+			for &s in margins.iter()
+			{
+				match s
+				{
+					MarginTop(frac) => writeln!(c, "set tmargin at screen {}", frac),
+					MarginBottom(frac) => writeln!(c, "set bmargin at screen {}", frac),
+					MarginLeft(frac) => writeln!(c, "set lmargin at screen {}", frac),
+					MarginRight(frac) => writeln!(c, "set rmargin at screen {}", frac),
+				};
+			}
+		}
+		self
+	}
+
 	/// Sets the palette used for 3D surface and image plots
 	///
 	/// # Arguments
